@@ -1,4 +1,4 @@
-import sys
+from http import HTTPStatus as status
 
 from collections import deque
 from inspect import iscoroutinefunction
@@ -292,8 +292,8 @@ class Routes(object):
 class Router(object):
     def __init__(self, configurator=None):
         self.finalized = False
-        self.initializers = set()
-        self.deinitializers = set()
+        self.initializers = deque()
+        self.deinitializers = deque()
         self.subdomains = {}
         self.subdomains[DEFAULT] = Routes()
         self._buckets = {}
@@ -314,16 +314,10 @@ class Router(object):
 
         metadata = preprocessor(scope)
         engine = self.subdomains.get(metadata[0]) or self.subdomains.get('*')
+
         response = await engine.handle(scope, receive, send, metadata, self)
-        await send({
-            'type': 'http.response.start',
-            'headers': response.headers,
-            'status': response.status
-        })
-        await send({
-            'type': 'http.response.body',
-            'body': response.body
-        })
+        await send({'type': 'http.response.start', 'headers': response.headers, 'status': response.status})
+        await send({'type': 'http.response.body', 'body': response.body})
 
     def abettor(self, method: str, route: str, handler: Handler, subdomain=DEFAULT):
         if not route.startswith('/'): raise UrlError
@@ -388,7 +382,7 @@ class Router(object):
             first = args[0]
             try: assert isinstance(first, Callable)
             except AssertionError: raise TypeError(error_message)
-            self.initializers.add(first)
+            self.initializers.append(first)
         else:
             first, second = args
 
@@ -398,13 +392,13 @@ class Router(object):
             try: assert isinstance(second, Callable)
             except AssertionError: raise TypeError(error_message)
 
-            if first == 'startup': self.initializers.add(second)
-            else: self.deinitializers.add(second)
+            if first == 'startup': self.initializers.append(second)
+            else: self.deinitializers.append(second)
 
     async def _register(self):
         i = len(self.initializers)
         while self.initializers:
-            initializer, c = self.initializers.pop(), len(self.initializers)
+            initializer, c = self.initializers.popleft(), len(self.initializers)
             index = i - c
             print(f'({index}): ', initializer.__name__, '\n')
             if iscoroutinefunction(initializer): await initializer(self)
@@ -413,7 +407,7 @@ class Router(object):
     async def _unregister(self):
         i = len(self.deinitializers)
         while self.deinitializers:
-            deinitializer, c = self.deinitializers.pop(), len(self.deinitializers)
+            deinitializer, c = self.deinitializers.popleft(), len(self.deinitializers)
             index = i - c
             print(f'({index}): ', deinitializer.__name__, '\n')
             if iscoroutinefunction(deinitializer): await deinitializer(self)
